==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/DeploymentTriggerPolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DeploymentTriggerPolicyBuilder extends io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluentImpl<io.fabric8.openshift.api.model.DeploymentTriggerPolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.DeploymentTriggerPolicy,io.fabric8.openshift.api.model.DeploymentTriggerPolicyBuilder>{
  public DeploymentTriggerPolicyBuilder() {
    this(false);
  }
  public DeploymentTriggerPolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new DeploymentTriggerPolicy(), validationEnabled);
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DeploymentTriggerPolicy(), validationEnabled);
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<?> fluent,io.fabric8.openshift.api.model.DeploymentTriggerPolicy instance) {
    this(fluent, instance, false);
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<?> fluent,io.fabric8.openshift.api.model.DeploymentTriggerPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withImageChangeParams(instance.getImageChangeParams()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicy instance) {
    this(instance,false);
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withImageChangeParams(instance.getImageChangeParams()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicy build() {
    DeploymentTriggerPolicy buildable = new DeploymentTriggerPolicy(fluent.getImageChangeParams(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeploymentTriggerPolicyBuilder that = (DeploymentTriggerPolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/DeploymentTriggerPolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DeploymentTriggerPolicyBuilder extends io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluentImpl<io.fabric8.openshift.api.model.DeploymentTriggerPolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.DeploymentTriggerPolicy,io.fabric8.openshift.api.model.DeploymentTriggerPolicyBuilder>{
  public DeploymentTriggerPolicyBuilder() {
    this(false);
  }
  public DeploymentTriggerPolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new DeploymentTriggerPolicy(), validationEnabled);
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DeploymentTriggerPolicy(), validationEnabled);
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<?> fluent,io.fabric8.openshift.api.model.DeploymentTriggerPolicy instance) {
    this(fluent, instance, false);
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<?> fluent,io.fabric8.openshift.api.model.DeploymentTriggerPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withImageChangeParams(instance.getImageChangeParams()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicy instance) {
    this(instance,false);
  }
  public DeploymentTriggerPolicyBuilder(io.fabric8.openshift.api.model.DeploymentTriggerPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withImageChangeParams(instance.getImageChangeParams()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.DeploymentTriggerPolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.DeploymentTriggerPolicy build() {
    DeploymentTriggerPolicy buildable = new DeploymentTriggerPolicy(fluent.getImageChangeParams(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeploymentTriggerPolicyBuilder that = (DeploymentTriggerPolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
